package dk.nsp.idsas.dao;

import org.apache.log4j.Logger;
import org.springframework.jdbc.core.BeanPropertyRowMapper;
import org.springframework.jdbc.core.namedparam.NamedParameterJdbcTemplate;

import javax.sql.DataSource;
import java.sql.Timestamp;
import java.util.HashMap;
import java.util.List;

public class BlurringDao {
    private static final Logger logger = Logger.getLogger(BlurringDao.class);

    private final NamedParameterJdbcTemplate jdbcTemplate;
    private final BeanPropertyRowMapper<BlurringEntity> rowMapper;

    public BlurringDao(DataSource dataSource) {
        jdbcTemplate = new NamedParameterJdbcTemplate(dataSource);
        rowMapper = BeanPropertyRowMapper.newInstance(BlurringEntity.class);
    }

    public void insert(BlurringEntity blurringEntity) {
        String query = "insert into blurring(patient_id, patient_id_type, organisation_id, organisation_id_type, expiry_date)" +
                "           values(:patient_id, :patient_id_type, :organisation_id, :organisation_id_type, :expiry_date)";
        HashMap<String, Object> parameters = new HashMap<>();
        parameters.put("patient_id", blurringEntity.getPatientId());
        parameters.put("patient_id_type", blurringEntity.getPatientIdType());
        parameters.put("organisation_id", blurringEntity.getOrganisationId());
        parameters.put("organisation_id_type", blurringEntity.getOrganisationIdType());
        parameters.put("expiry_date", Timestamp.from(blurringEntity.getExpiryDate()));

        jdbcTemplate.update(query, parameters);
    }

    public List<BlurringEntity> getActiveBlurrings(String patientId, String patientIdType) {
        String query = "select * from blurring" +
                "           where patient_id = :patient_id and patient_id_type = :patient_id_type and expiry_date > now()";
        HashMap<String, Object> parameters = new HashMap<>();
        parameters.put("patient_id", patientId);
        parameters.put("patient_id_type", patientIdType);
        return jdbcTemplate.query(query, parameters, rowMapper);
    }
}
